==> aiogeoip-0.0.1.tar.gz: aiogeoip-0.0.1/README.md <==
![AioGeoIP logo](https://i.pinimg.com/originals/01/a7/7b/01a77baccfefd2b5c0da749a1181bf83.png)

---
<p align="center">
        <b>Real asynchronous</b> geolocation by IP address with <b><a href="https://docs.python.org/3/library/asyncio.html">Asyncio support</a></b>.
</p>
<p align="center">
        Get the geolocation of IPs <b>asynchronously</b> or <b>synchronously</b> using the <a href="https://ip-api.com/" target="_blank"><b>IP-API</b></a> service with <b>cached</b> requests for greater optimization of your software, providing back end with <a href="https://docs.python.org/3/library/urllib.request.html" target="_blank"><b>urllib</b></a> and <a href="https://requests.readthedocs.io/en/master/" target="_blank"><b>requests</b></a>.
</p>

<p align="center">
        <img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/py-paulo/aiogeoip/Pylint?label=pylint&style=flat-square">
        <img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/py-paulo/aiogeoip/Python%20package?label=py-package&style=flat-square">
        <img alt="Read the Docs" src="https://img.shields.io/readthedocs/aiogeoip?style=flat-square">
        <img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/py-paulo/aiogeoip?style=flat-square">
        <img alt="GitHub" src="https://img.shields.io/github/license/py-paulo/aiogeoip?style=flat-square">
</p>

<p align="center">
  <a href="https://aiogeoip.readthedocs.io/en/latest/" target="_blank">Docs</a> +
  <a href="#">Pip</a> +
  <a href="#">Multiplataform</a> +
  <a href="#">CHANGELOG</a>
</p>

---

==> aiogeoip-0.0.2.tar.gz: aiogeoip-0.0.2/README.md <==
![AioGeoIP logo](https://i.pinimg.com/originals/01/a7/7b/01a77baccfefd2b5c0da749a1181bf83.png)

---
<p align="center">
        <b>Real asynchronous</b> geolocation by IP address with <b><a href="https://docs.python.org/3/library/asyncio.html">Asyncio support</a></b>.
</p>
<p align="center">
        Get the geolocation of IPs <b>asynchronously</b> or <b>synchronously</b> using the <a href="https://ip-api.com/" target="_blank"><b>IP-API</b></a> service with <b>cached</b> requests for greater optimization of your software, providing back end with <a href="https://docs.python.org/3/library/urllib.request.html" target="_blank"><b>urllib</b></a> and <a href="https://requests.readthedocs.io/en/master/" target="_blank"><b>requests</b></a>.
</p>

<p align="center">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/aiogeoip?style=flat-square">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/aiogeoip?style=flat-square">
        <img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/py-paulo/aiogeoip/Pylint?label=pylint&style=flat-square">
        <img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/py-paulo/aiogeoip/Python%20package?label=py-package&style=flat-square">
        <img alt="Read the Docs" src="https://img.shields.io/readthedocs/aiogeoip?style=flat-square">
        <img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/py-paulo/aiogeoip?style=flat-square">
        <img alt="GitHub" src="https://img.shields.io/github/license/py-paulo/aiogeoip?style=flat-square">
</p>

<p align="center">
  <a href="https://aiogeoip.readthedocs.io/en/latest/" target="_blank">Docs</a> +
  <a href="#">Pip</a> +
  <a href="#">Multiplataform</a> +
  <a href="#">CHANGELOG</a>
</p>

---
